==> haskell-ghcide-2.1.0.0-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-LH4574L1LpH1xR0Ndxz7q3
key:                  ghcide-2.1.0.0-LH4574L1LpH1xR0Ndxz7q3
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  286370aaf6d62475f038f30ec9d75db6
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-LH4574L1LpH1xR0Ndxz7q3
depends:
    Diff-0.5-7WhUZGNNqmv2AHgG88fLzI Glob-0.10.2-HuOZ1KDUH0g3Y8N4carev1
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r
    aeson-pretty-0.8.10-FoZoq2L63jY6PFOqAzdYHf array-0.5.4.0
    async-2.2.5-EP91qAI3cOI8P3d6QWskI6 base-4.17.2.1
    base16-bytestring-1.0.2.0-UlhuRwgBIQ75TYKUiV4JF binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4HYxnyEi2mnBK2ectdARDN
    co-log-core-0.3.2.5-CiFyX5luoGE3ZQ6hLne706 containers-0.6.7
    cryptohash-sha1-0.11.101.0-AZVBBwcxRiC1GhqzQ4shyQ
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd deepseq-1.4.8.0
    dependent-map-0.4.0.0-8t0BVFx1GFo2LKiZ15FX8s
    dependent-sum-0.7.2.0-L02c9L93evEfy8hkLdmys directory-1.3.7.1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    enummapset-0.7.3.0-An2oRLX2NsHDaOoRl68IYD exceptions-0.10.5
    extra-1.7.16-OM7JeG07e46segIIOxZE2 filepath-1.4.2.2
    fingertree-0.1.6.2-HuIIQftuSxH1m7bMM15jdm
    focus-1.0.3.2-BBKFwVZ7aLxKc6tqdaGTG9 ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-IudOAK6M6btIjBow32mz8P
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-28GS6rAsBbwH4xklnhcCL8
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    hie-bios-0.12.0-K9GK47afxR8HLNirl6axuW
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hiedb-0.4.3.0-HPmyBMbqSFiDJppwIXSROP
    hls-graph-2.1.0.0-aqSM381LHP6Mr8PQB4eJo
    hls-plugin-api-2.1.0.0-I3AvIb2Kf1m5CXfEOeBoCv
    implicit-hie-0.1.4.0-LeWGayfmKm6EKtlrq8WweO
    implicit-hie-cradle-0.5.0.1-78cgkxLYlIN5Bc3eFV2GBV
    lens-5.3.3-6oW8YfnpumtF66FcI0BTsr
    list-t-1.0.5.7-6HMu2twXA5zBkE80tr321F
    lsp-2.1.0.0-736YImsOgnd1fKorlgmicl
    lsp-types-2.0.1.0-rbTn4aGunV9tjBHdYuF11 mtl-2.2.2
    opentelemetry-0.8.0-Gsv4yAYi9puJrNEMVuSP0P
    optparse-applicative-0.18.1.0-DIJ4MbtGu3QDLh3tqkvHS0
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-2fDIWQCpfcFF0VMlKg6ON0
    prettyprinter-ansi-terminal-1.1.3-BFsIH7JRjJdG9vbANpn0JH
    random-1.2.1.3-8ADb21VvJl3AtsgmJLZ0Jg
    regex-tdfa-1.3.2.4-5lZgJt0yJqSDd9oY2H08fk
    row-types-1.0.1.2-7cQtIZqpIUJL7SOEb6Hq6Y
    safe-exceptions-0.1.7.4-BHXVcDz6IbLBHc1gNLrRaN
    sorted-list-0.2.3.1-KiT5KkWVSzr8zB2oFJoGg1
    sqlite-simple-0.4.19.0-3VppcgLKIBr1cOdlSJV1rc stm-2.5.1.0
    stm-containers-1.2.1.1-2PLmCEBoAPrE81H55Em4hL
    syb-0.7.3-Dk2TUQSTxWd5yTqOEWpD7k text-2.0.2
    text-rope-0.3-Dmhgp1oJtpL5EHUV1LaKxV time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-KNqQlHOV1yC27z4clRFnX2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    vector-0.13.2.0-9W9rHKyBrY08EKASla5WO0

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghcide-2.1.0.0-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghcide.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.1.0.0
visibility:           public
id:                   ghcide-2.1.0.0-FU6QMphKYoWLgKaCkx3pXn
key:                  ghcide-2.1.0.0-FU6QMphKYoWLgKaCkx3pXn
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  88479f48b7d35f63186085c6c4d800b6
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Spans.AtPoint Development.IDE.Spans.Common
    Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghcide-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.1.0.0-FU6QMphKYoWLgKaCkx3pXn
depends:
    Diff-0.5-7WhUZGNNqmv2AHgG88fLzI Glob-0.10.2-HuOZ1KDUH0g3Y8N4carev1
    aeson-2.1.2.1-9rGsBPhyshTKvPzkopJx8r
    aeson-pretty-0.8.10-FoZoq2L63jY6PFOqAzdYHf array-0.5.4.0
    async-2.2.5-EP91qAI3cOI8P3d6QWskI6 base-4.17.2.1
    base16-bytestring-1.0.2.0-UlhuRwgBIQ75TYKUiV4JF binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-4HYxnyEi2mnBK2ectdARDN
    co-log-core-0.3.2.5-CiFyX5luoGE3ZQ6hLne706 containers-0.6.7
    cryptohash-sha1-0.11.101.0-AZVBBwcxRiC1GhqzQ4shyQ
    data-default-0.7.1.3-3HSSfTTpRalIdOguxliHyd deepseq-1.4.8.0
    dependent-map-0.4.0.0-8t0BVFx1GFo2LKiZ15FX8s
    dependent-sum-0.7.2.0-L02c9L93evEfy8hkLdmys directory-1.3.7.1
    dlist-1.0-E99MqJW5mmB4kr4PCgIESI
    enummapset-0.7.3.0-An2oRLX2NsHDaOoRl68IYD exceptions-0.10.5
    extra-1.7.16-OM7JeG07e46segIIOxZE2 filepath-1.4.2.2
    fingertree-0.1.6.2-HuIIQftuSxH1m7bMM15jdm
    focus-1.0.3.2-EgafqfI18jKLjVGmA0bewF ghc-9.4.8 ghc-boot-9.4.8
    ghc-boot-th-9.4.8 ghc-check-0.5.0.8-IudOAK6M6btIjBow32mz8P
    ghc-paths-0.1.0.12-8lmZj1VFo8V7iNy4rcXCyj
    ghc-trace-events-0.1.2.9-7ocQkvnjYWsA9rDcBsLuv7
    haddock-library-1.11.0-28GS6rAsBbwH4xklnhcCL8
    hashable-1.4.7.0-LvsgkXc0RJl9ehxeji9DTo
    hie-bios-0.12.0-K9GK47afxR8HLNirl6axuW
    hie-compat-0.3.1.2-IkeVSMKPoXJ5qEiKo06jB7
    hiedb-0.4.3.0-HPmyBMbqSFiDJppwIXSROP
    hls-graph-2.1.0.0-VDpIWprLxG8e0VCshLjoT
    hls-plugin-api-2.1.0.0-Jk0T9FP7LsOBtoIb3dExQN
    implicit-hie-0.1.4.0-LeWGayfmKm6EKtlrq8WweO
    implicit-hie-cradle-0.5.0.1-78cgkxLYlIN5Bc3eFV2GBV
    lens-5.3.3-6oW8YfnpumtF66FcI0BTsr
    list-t-1.0.5.7-6HMu2twXA5zBkE80tr321F
    lsp-2.1.0.0-736YImsOgnd1fKorlgmicl
    lsp-types-2.0.1.0-rbTn4aGunV9tjBHdYuF11 mtl-2.2.2
    opentelemetry-0.8.0-Gsv4yAYi9puJrNEMVuSP0P
    optparse-applicative-0.18.1.0-DIJ4MbtGu3QDLh3tqkvHS0
    parallel-3.2.2.0-KJ5o3ImR3G8wdLWLqGjpy
    prettyprinter-1.7.1-2fDIWQCpfcFF0VMlKg6ON0
    prettyprinter-ansi-terminal-1.1.3-BFsIH7JRjJdG9vbANpn0JH
    random-1.2.1.3-8ADb21VvJl3AtsgmJLZ0Jg
    regex-tdfa-1.3.2.4-5lZgJt0yJqSDd9oY2H08fk
    row-types-1.0.1.2-7cQtIZqpIUJL7SOEb6Hq6Y
    safe-exceptions-0.1.7.4-BHXVcDz6IbLBHc1gNLrRaN
    sorted-list-0.2.3.1-KiT5KkWVSzr8zB2oFJoGg1
    sqlite-simple-0.4.19.0-3VppcgLKIBr1cOdlSJV1rc stm-2.5.1.0
    stm-containers-1.2.1.1-HDMSUHDkBomL4dX6nqGW13
    syb-0.7.3-Dk2TUQSTxWd5yTqOEWpD7k text-2.0.2
    text-rope-0.3-Dmhgp1oJtpL5EHUV1LaKxV time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unliftio-0.2.25.1-KNqQlHOV1yC27z4clRFnX2
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20.1-LlrDkEbe6ka5Vid8Nf7fMl
    vector-0.13.2.0-9W9rHKyBrY08EKASla5WO0

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
